@@ -1,10 +1,10 @@
 // MediaInfo_CLI - A Command Line Interface for MediaInfoLib
-// Copyright (C) 2002-2011 MediaArea.net SARL, Info@MediaArea.net
+// Copyright (C) 2002-2012 MediaArea.net SARL, Info@MediaArea.net
 //
 // This program is free software: you can redistribute it and/or modify it
 // under the terms of the GNU Lesser General Public License as published by
 // the Free Software Foundation, either version 3 of the License, or
-// any later version.
+// (at your option) any later version.
 //
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -18,10 +18,8 @@
 //+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 
 //---------------------------------------------------------------------------
-#include <iostream>
 #include <string>
 #include <vector>
-#include <fstream>
 #ifdef __BORLANDC__
     #pragma hdrstop
 #endif
@@ -227,12 +225,6 @@ void LogFile_Action(ZenLib::Ztring Inform)
 void CallBack_Set(Core &MI, void* Event_CallBackFunction)
 {
     //CallBack configuration
-    #if defined(UNICODE)
-        std::wostringstream Event_CallBackFunction_Text;
-    #else
-        std::ostringstream Event_CallBackFunction_Text;
-    #endif
-    Event_CallBackFunction_Text<<"CallBack=memory://"<<(size_t)Event_CallBackFunction;
-    MI.Menu_Option_Preferences_Option(_T("Event_CallBackFunction"), Event_CallBackFunction_Text.str());
+    MI.Menu_Option_Preferences_Option(_T("Event_CallBackFunction"), _T("CallBack=memory://")+ZenLib::Ztring::ToZtring((size_t)Event_CallBackFunction));
 }
 
